==> tkvoice-1.2a.tar.gz: tkvoice-1.2a/TCL/tkvsetupfax.tcl <==
# tkvsetupfax.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvfax
catch {destroy $w}
toplevel $w
wm title $w "tkVoice FAX Setup"
wm iconname $w "tkVoice FAX Setup"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w

global drawfax
 
proc restartmsg {} {
global w
tk_messageBox -icon warning -type ok \
        -title "FAX SUPPORT WARNING" -parent $w\
        -message "\"RESTART\" of tkVoice is required for FAX support changes to take affect.\n\nRemember to \"SAVE\"."
}

######################################################
# tkvoice setup image
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoicefax}
image create photo tkvoicefax -file [file join $tkvoicedir/image/tkvoicefax.gif]

label $w.gif.tkvoicesetupfax -image tkvoicefax -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoicesetupfax -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right


#########################

frame $w.top
pack $w.top -side top -expand yes -pady .3c -padx .5c
checkbutton $w.top.drawfax -text "FAX support ON/OFF" -variable drawfax \
            -relief flat -onvalue "1" -offvalue "0" -command "restartmsg"
pack $w.top.drawfax -side top -pady 2 -anchor w

label $w.msg2 -font $font -wraplength 4i -justify left -text "   \"FAX\" spool directory ?"
label $w.msg3 -font $font -wraplength 4i -justify left -text "\n\t\"INCOMING\" directory ?\n\t(with respect to $faxdir)"
label $w.msg4 -font $font -wraplength 4i -justify left -text "\n\t\"OUTGOING\" directory ?\n\t(with respect to $faxdir)"

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.save -text SAVE -command "savefax; destroy $w"
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.save $w.buttons.cancel -side left -expand 1

foreach i "faxdir faxin faxout" {
    frame $w.$i -bd 2
    entry $w.$i.entry -relief sunken -width 40 -textvariable $i -background snow2
    label $w.$i.label
    pack $w.$i.entry -side right
    pack $w.$i.label -side left
}
$w.faxdir.label config   -text "FAX Spool Directory:"
$w.faxin.label config    -text "Incoming Directory :"
$w.faxout.label config   -text "Outgoing Directory :"
pack $w.msg2 $w.faxdir $w.msg3 $w.faxin $w.msg4 $w.faxout -side top -fill x
focus $w.faxdir.entry
bind $w.faxdir.entry <Return> {focus $w.faxin.entry}
bind $w.faxin.entry <Return> {focus $w.faxout.entry}
bind $w.faxout.entry <Return> {focus $w.faxdir.entry}

==> tkvoice-1.5.tar.gz: tkvoice-1.5/TCL/tkvsetupfax.tcl <==
# tkvsetupfax.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvfax
catch {destroy $w}
toplevel $w
wm title $w "tkVoice FAX Setup"
wm iconname $w "tkVoice FAX Setup"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w

global drawfax
set bgcolor "#eeeeee"

#######################################
 
proc restartmsg {} {
global w
tk_messageBox -icon warning -type ok \
        -title "FAX SUPPORT WARNING" -parent $w\
        -message "\"RESTART\" of tkVoice is required for FAX support changes to take affect.\n\nRemember to \"SAVE\"."
}

######################################################
# tkvoice setup image
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoicefax}
image create photo tkvoicefax -file [file join $tkvoicedir/image/tkvoicefax.gif]

label $w.gif.tkvoicesetupfax -image tkvoicefax -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoicesetupfax -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right


#########################

frame $w.top
pack $w.top -side top -expand yes -pady .5c -padx .5c
checkbutton $w.top.drawfax -text "FAX support ON/OFF" -variable drawfax \
            -relief flat -onvalue "1" -offvalue "0" -command "restartmsg"
pack $w.top.drawfax -side top -pady .1c -anchor w

label $w.msg2 -font $font -wraplength 4i -justify left -text "   \"FAX\" spool directory ?"
label $w.msg3 -font $font -wraplength 4i -justify left -text "\n\t\"INCOMING\" directory ?\n\t(with respect to $faxdir)"
label $w.msg4 -font $font -wraplength 4i -justify left -text "\n\t\"OUTGOING\" directory ?\n\t(with respect to $faxdir)"

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.save -text SAVE -command "savefax; destroy $w"
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.save $w.buttons.cancel -pady .3c -side left -expand 1

foreach i "faxdir faxin faxout" {
    frame $w.$i -bd 2
    entry $w.$i.entry -relief sunken -width 40 -textvariable $i -background $bgcolor
    label $w.$i.label
    pack $w.$i.entry -side right
    pack $w.$i.label -side left
}
$w.faxdir.label config   -text "FAX Spool Directory:"
$w.faxin.label config    -text "Incoming Directory :"
$w.faxout.label config   -text "Outgoing Directory :"
pack $w.msg2 $w.faxdir $w.msg3 $w.faxin $w.msg4 $w.faxout -side top -fill x
focus $w.faxdir.entry
bind $w.faxdir.entry <Return> {focus $w.faxin.entry}
bind $w.faxin.entry <Return> {focus $w.faxout.entry}
bind $w.faxout.entry <Return> {focus $w.faxdir.entry}
